[![Release](https://github.com/grupodyd/python-qanty/actions/workflows/python-publish.yml/badge.svg)](https://github.com/grupodyd/python-qanty/actions/workflows/release.yml)
[![MIT licensed](https://img.shields.io/badge/license-MIT-blue.svg)](./LICENSE)
[![pypi](https://badge.fury.io/py/qanty.svg)](https://pypi.org/project/qanty/)
# python-qanty
Python package for integration of Qanty in other applications
